AsyncQueryMsgFns

Trait AsyncQueryMsgFns 

pub trait AsyncQueryMsgFns<Chain: AsyncWasmQuerier + ChainState, CwOrchQueryMsgType: Sync>: AsyncCwOrchQuery<Chain, QueryMsg = CwOrchQueryMsgType>
where QueryMsg: Into<CwOrchQueryMsgType>,
{ // Provided methods async fn active_channel_async(&self) -> Result<Option<String>, CwEnvError> { ... } async fn pair_async(&self) -> Result<Option<Pair>, CwEnvError> { ... } async fn remote_address_async( &self, local_address: impl Into<String>, ) -> Result<Option<String>, CwEnvError> { ... } async fn block_max_gas_async(&self) -> Result<Uint64, CwEnvError> { ... } async fn ack_infos_async( &self, limit: Option<u8>, start_after: Option<u64>, ) -> Result<AckInfosResponse, CwEnvError> { ... } }
Automatically derived trait that allows you to call the variants of the message directly without the need to construct the struct yourself.

Provided Methods

async fn active_channel_async(&self) -> Result<Option<String>, CwEnvError>

Automatically generated wrapper around QueryMsg::ActiveChannel variant

async fn pair_async(&self) -> Result<Option<Pair>, CwEnvError>

Automatically generated wrapper around QueryMsg::Pair variant

async fn remote_address_async( &self, local_address: impl Into<String>, ) -> Result<Option<String>, CwEnvError>

Automatically generated wrapper around QueryMsg::RemoteAddress variant

async fn block_max_gas_async(&self) -> Result<Uint64, CwEnvError>

Automatically generated wrapper around QueryMsg::BlockMaxGas variant

async fn ack_infos_async( &self, limit: Option<u8>, start_after: Option<u64>, ) -> Result<AckInfosResponse, CwEnvError>

Automatically generated wrapper around QueryMsg::AckInfos variant

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<Chain: AsyncWasmQuerier + ChainState, CwOrchQueryMsgType: Sync, SupportedContract> AsyncQueryMsgFns<Chain, CwOrchQueryMsgType> for SupportedContract
where QueryMsg: Into<CwOrchQueryMsgType>, SupportedContract: AsyncCwOrchQuery<Chain, QueryMsg = CwOrchQueryMsgType>,

Available on non-WebAssembly only.