ExecuteMsgFns

Trait ExecuteMsgFns 

pub trait ExecuteMsgFns<Chain: TxHandler, CwOrchExecuteMsgType>: CwOrchExecute<Chain, ExecuteMsg = CwOrchExecuteMsgType>
where ExecuteMsg: Into<CwOrchExecuteMsgType>,
{ // Provided method fn ibc_execute( &self, msgs: Vec<EvmMsg<String>>, timeout_seconds: impl Into<Uint64>, callback: Option<CallbackRequest>, ) -> Result<TxResponse<Chain>, CwEnvError> { ... } }
Automatically derived trait that allows you to call the variants of the message directly without the need to construct the struct yourself.

Provided Methods

fn ibc_execute( &self, msgs: Vec<EvmMsg<String>>, timeout_seconds: impl Into<Uint64>, callback: Option<CallbackRequest>, ) -> Result<TxResponse<Chain>, CwEnvError>

Automatically generated wrapper around ExecuteMsg::Execute variant

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<Chain: TxHandler, CwOrchExecuteMsgType, SupportedContract> ExecuteMsgFns<Chain, CwOrchExecuteMsgType> for SupportedContract
where ExecuteMsg: Into<CwOrchExecuteMsgType>, SupportedContract: CwOrchExecute<Chain, ExecuteMsg = CwOrchExecuteMsgType>,

Available on non-WebAssembly only.